import { FieldNode, GraphQLObjectType, GraphQLOutputType, GraphQLResolveInfo } from "graphql";
import { ObjectPath } from "./ast";
export interface GraphQLJitResolveInfo extends GraphQLResolveInfo {
    fieldExpansion: FieldExpansion | LeafField;
}
export interface FieldExpansion {
    [returnType: string]: TypeExpansion;
}
export interface TypeExpansion {
    [fieldName: string]: FieldExpansion | LeafField;
}
declare const LeafFieldSymbol: unique symbol;
export interface LeafField {
    [LeafFieldSymbol]: true;
}
export declare function isLeafField(obj: LeafField | FieldExpansion): obj is LeafField;
/**
 * Compute the GraphQLJitResolveInfo's `fieldExpansion` and return a function
 * that returns the computed resolveInfo. This thunk is registered in
 * context.dependencies for the field's resolveInfoName
 */
export declare function createResolveInfoThunk({ schema, fragments, operation, parentType, fieldName, fieldType, fieldNodes }: {
    schema: GraphQLResolveInfo["schema"];
    fragments: GraphQLResolveInfo["fragments"];
    operation: GraphQLResolveInfo["operation"];
    parentType: GraphQLObjectType;
    fieldType: GraphQLOutputType;
    fieldName: string;
    fieldNodes: FieldNode[];
}): (rootValue: any, variableValues: any, path: ObjectPath) => GraphQLJitResolveInfo;
export {};
